@@ -151,9 +151,8 @@ class Storage(driver.Base):
              while len(l) > 0:
                  object_instance.upload_flow(None, l, True)
                  l = fp.read(self.buffer_size)
-         except Exception as e :
+         except IOError as e :
             logger.error("stream_write error:%s" % e)
-            raise e
          
 #    def stream_write(self, path, fp):
 #        logger.info("stream_write path:%s" % path)
